# -*- coding: utf-8 -*-
# @Author: SashaChernykh
# @Date: 2018-01-26 10:06:04
# @Last Modified time: 2018-01-27 07:40:52
"""Check files for correct head metadata.

Check, that files contains «Описание пакета:», «Процесс тренировки:» and so on.
"""
import logbook

import os

# Do not use «from <module> import *»
# http://bit.ly/2CuW5GS
from pyfancy.pyfancy import pyfancy

from erichek.eric_config import ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS
LOG = logbook.Logger("eric_head logbook")

HEAD_DATA = True

# Multiple True
# https://stackoverflow.com/a/11717045/5951529
DESCRIPTION_FAILURE_TESTS, TRAINING_PROCESS_FAILURE_TESTS, FIRST_EXAMPLE_FAILURE_TESTS, \
    FIRST_ANSWER_FAILURE_TESTS, SECOND_EXAMPLE_FAILURE_TESTS, SECOND_ANSWER_FAILURE_TESTS, \
    PROOFS_FAILURE_TESTS, AUTHORS_FAILURE_TESTS, LINK_FAILURE_TESTS, PACKAGE_LINK_FAILURE_TESTS = (
        True,) * 10


def red_foreground(redtext):
    """Red foreground for error messages.

    Red foreground for error messages.

    Arguments:
        redtext {str} -- text, which will be colored in red.
    """
    LOG.error(pyfancy().red().bold(redtext))


def green_foreground(greentext):
    """Green foreground for notice messages.

    Green foreground for error messages.

    Arguments:
        greentext {str} -- text, which will be colored in green.
    """
    LOG.notice(pyfancy().green().bold(greentext))


def eric_head_function():
    """Check, that files contains metadata.

    Check for next metadata:

        + Описание пакета:
        + Процесс тренировки:
        + Примечания:
        + Пример вопроса 1:
        + Ответ к примеру вопроса 1:
        + Пример вопроса 2:
        + Ответ к примеру вопроса 2:
        + Источник(и):
        + Автор(ы), редакторы и рецензенты (если есть) материалов источника(ов):
        + Ссылка(и) на источник(и):
        + Постоянный адрес пакета:
    """
    # Get list all filenames in a directory
    # https://stackoverflow.com/a/1120736/5951529
    for filename in ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS:

        filename_without_path = os.path.basename(filename)

        # File content in folder
        each_file_in_folder = open(filename, encoding='windows-1251').read()

        # Find head data
        if 'Описание пакета:' in each_file_in_folder:
            LOG.debug(
                '«Описание пакета:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Описание пакета:»')
            global DESCRIPTION_FAILURE_TESTS
            DESCRIPTION_FAILURE_TESTS = False

        if 'Процесс тренировки:' in each_file_in_folder:
            LOG.debug(
                '«Процесс тренировки:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Процесс тренировки:»')
            global TRAINING_PROCESS_FAILURE_TESTS
            TRAINING_PROCESS_FAILURE_TESTS = False

        if 'Пример вопроса 1:' in each_file_in_folder:
            LOG.debug(
                '«Пример вопроса 1:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Пример вопроса 1:»')
            global FIRST_EXAMPLE_FAILURE_TESTS
            FIRST_EXAMPLE_FAILURE_TESTS = False

        if 'Ответ к примеру вопроса 1:' in each_file_in_folder:
            LOG.debug(
                '«Ответ к примеру вопроса 1:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Ответ к примеру вопроса 1:»')
            global FIRST_ANSWER_FAILURE_TESTS
            FIRST_ANSWER_FAILURE_TESTS = False

        if 'Пример вопроса 2:' in each_file_in_folder:
            LOG.debug(
                '«Пример вопроса 2:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Пример вопроса 2:»')
            global SECOND_EXAMPLE_FAILURE_TESTS
            SECOND_EXAMPLE_FAILURE_TESTS = False

        if 'Ответ к примеру вопроса 2:' in each_file_in_folder:
            LOG.debug(
                '«Ответ к примеру вопроса 2:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Ответ к примеру вопроса 2:»')
            global SECOND_ANSWER_FAILURE_TESTS
            SECOND_ANSWER_FAILURE_TESTS = False

        if 'Источник(и):' in each_file_in_folder:
            LOG.debug(
                '«Источник(и):» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Источник(и):»')
            global PROOFS_FAILURE_TESTS
            PROOFS_FAILURE_TESTS = False

        if 'Автор(ы), редакторы и рецензенты (если есть) материалов источника(ов):' in each_file_in_folder:
            LOG.debug(
                '«Автор(ы), редакторы и рецензенты (если есть) материалов источника(ов):» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Автор(ы), редакторы и рецензенты (если есть) материалов источника(ов):»')
            global AUTHORS_FAILURE_TESTS
            AUTHORS_FAILURE_TESTS = False

        if 'Ссылка(и) на источник(и):' in each_file_in_folder:
            LOG.debug(
                '«Ссылка(и) на источник(и):» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Ссылка(и) на источник(и):»')
            global LINK_FAILURE_TESTS
            LINK_FAILURE_TESTS = False

        if 'Постоянный адрес пакета:' in each_file_in_folder:
            LOG.debug(
                '«Постоянный адрес пакета:» contains in ' +
                filename_without_path)
        else:
            red_foreground(
                filename_without_path +
                ' not contains «Постоянный адрес пакета:»')
            global PACKAGE_LINK_FAILURE_TESTS
            PACKAGE_LINK_FAILURE_TESTS = False


def eric_head_summary():
    """Report, contains head data in all files or no."""
    eric_head_function()

    if all([DESCRIPTION_FAILURE_TESTS, TRAINING_PROCESS_FAILURE_TESTS, FIRST_EXAMPLE_FAILURE_TESTS,
            FIRST_ANSWER_FAILURE_TESTS, SECOND_EXAMPLE_FAILURE_TESTS, SECOND_ANSWER_FAILURE_TESTS,
            PROOFS_FAILURE_TESTS, AUTHORS_FAILURE_TESTS, LINK_FAILURE_TESTS, PACKAGE_LINK_FAILURE_TESTS]):
        global HEAD_DATA
        HEAD_DATA = True
        green_foreground(
            'All files contains correct head data')
    else:
        HEAD_DATA = False
        red_foreground('One or more packages not contains one or more head data. '
                       'Please, add correct head data to your package.')



# -*- coding: utf-8 -*-
# @Author: SashaChernykh
# @Date: 2018-01-22 07:23:52
# @Last Modified time: 2018-01-26 17:23:32
"""Check files for body.

Check, contains files of directory <body> or no.
"""
import logbook

import os

# Do not use «from <module> import *»
# http://bit.ly/2CuW5GS
from pyfancy.pyfancy import pyfancy

from erichek.eric_config import ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS


LOG = logbook.Logger("eric_body logbook")

BODY_EXIST = True


def red_foreground(redtext):
    """Red foreground for error messages.

    Red foreground for error messages.

    Arguments:
        redtext {str} -- text, which will be colored in red.
    """
    LOG.error(pyfancy().red().bold(redtext))


def green_foreground(greentext):
    """Green foreground for notice messages.

    Green foreground for error messages.

    Arguments:
        greentext {str} -- text, which will be colored in green.
    """
    LOG.notice(pyfancy().green().bold(greentext))


def eric_body_function():
    """Check, contains body in a file, or no."""
    # Get list all filenames in a directory
    # https://stackoverflow.com/a/1120736/5951529
    for filename in ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS:

        filename_without_path = os.path.basename(filename)

        # Check if string in a file
        # https://stackoverflow.com/a/4944929/5951529
        # Encoding for Travis CI, see
        # https://stackoverflow.com/a/31492722/5951529
        # https://github.com/travis-ci/travis-ci/issues/8993#issuecomment-354674238
        # https://github.com/travis-ci/travis-ci/issues/8993#issuecomment-354681085
        if "<body>" in open(filename, encoding='windows-1251').read():
            LOG.debug(filename_without_path + " contains <body>")

        else:
            red_foreground(
                "File " +
                filename_without_path +
                " not contain <body>. Please, add <body> in " +
                filename_without_path +
                ".")
            global BODY_EXIST
            BODY_EXIST = False


def eric_body_summary():
    """Report, contains <body> in all files or no.

    Use flags, see https://stackoverflow.com/a/48052480/5951529
    """
    eric_body_function()
    if BODY_EXIST:
        green_foreground(
            "All files contains <body>")

    if not BODY_EXIST:
        red_foreground(
            "Not all files contains <body>. Please, correct it.")



# -*- coding: utf-8 -*-
# @Author: SashaChernykh
# @Date: 2018-01-22 07:32:05
# @Last Modified time: 2018-02-01 19:15:27
"""Run tests.

Main file for running Erichek tests.
"""

import erichek.eric_asterisks as eric_asterisks
import erichek.eric_body as eric_body
import erichek.eric_encoding as eric_encoding
import erichek.eric_head as eric_head
import logbook

from clize import run
from erichek.eric_config import clize_log_level
from erichek.eric_config import v
from erichek.eric_config import version

# Pyfancy — output color highighting
# Disabled green background, because bad color in AppVeyor
# https://github.com/appveyor/ci/issues/1138#issuecomment-355525721
# Import class, not a module
# https://stackoverflow.com/a/4534443/5951529
from pyfancy.pyfancy import pyfancy

# ASCII-art printing
# [BUG] ASCII-ART output, when --help or --version
# https://github.com/epsy/clize/issues/38#issue-290426111
# https://stackoverflow.com/a/9638532/5951529
# import sys
# from colorama import init
# from pyfiglet import figlet_format
# from termcolor import cprint

# strip colors if stdout is redirected
# init(strip=not sys.stdout.isatty())

LOG = logbook.Logger("summary logbook")


def red_foreground(redtext):
    """Red foreground for error messages.

    Red foreground for error messages.

    Arguments:
        redtext {str} -- text, which will be colored in red.
    """
    LOG.error(pyfancy().red().bold(redtext))


def green_foreground(greentext):
    """Green foreground for notice messages.

    Green foreground for error messages.

    Arguments:
        greentext {str} -- text, which will be colored in green.
    """
    LOG.notice(pyfancy().green().bold(greentext))


def main():
    """Run Erichek.

    Run all modules of Erichek.
    If no errors — validation success,
    Else — exit(1).
    """
    run(clize_log_level, alt=[version, v], exit=False)
    eric_encoding.eric_encoding_summary()
    eric_body.eric_body_summary()
    eric_asterisks.eric_asterisks_summary()
    eric_head.eric_head_summary()

    # If all instead of multiple if and:
    # https://stackoverflow.com/a/9504681/5951529
    if all([eric_body.BODY_EXIST, eric_encoding.ENCODING_WINDOWS_1251, eric_asterisks.ASTERISKS_EXISTS,
            eric_head.HEAD_DATA]):
        green_foreground(
            "Congratulations! You haven't errors in your packages!")
        # cprint(figlet_format('\nSuccess', font='starwars'),
        # 'white', 'on_green', attrs=['bold'])
    else:
        red_foreground(
            "You have errors in your packages. Please, fix them.")
        # cprint(figlet_format('\nFailure', font='starwars'),
        # 'yellow', 'on_red', attrs=['bold'])
        exit(1)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
# @Author: SashaChernykh
# @Date: 2018-01-22 19:58:48
# @Last Modified time: 2018-02-02 08:37:57
"""Asterisks Checker.

Check, if asterisks contains in each line of package for Eric room.

Do not check:
    1. lines before <body> and line with <body>,
    2. <!-- comments -->.
"""
import logbook

import os

# Do not use «from <module> import *»
# http://bit.ly/2CuW5GS
from pyfancy.pyfancy import pyfancy

from erichek.eric_config import ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS


LOG = logbook.Logger("eric_asterisks logbook")

ASTERISKS_EXISTS = True


def red_foreground(redtext):
    """Red foreground for error messages.

    Red foreground for error messages.

    Arguments:
        redtext {str} -- text, which will be colored in red.
    """
    LOG.error(pyfancy().red().bold(redtext))


def green_foreground(greentext):
    """Green foreground for notice messages.

    Green foreground for error messages.

    Arguments:
        greentext {str} -- text, which will be colored in green.
    """
    LOG.notice(pyfancy().green().bold(greentext))


def eric_asterisks_function():
    """Check, contains asterisks in each line of a file, or no."""
    for filename in ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS:

        filename_without_path = os.path.basename(filename)
        # Lines to list
        # https://stackoverflow.com/a/3277515/5951529
        with open(filename, encoding='windows-1251') as filename_as_list:
            submit_file_as_list = filename_as_list.readlines()
            # New list after <body>
            # https://stackoverflow.com/a/35880897/5951529
            # Except: if <body> not contains, Erichek output ValueError.
            # Propose to add <body>.
            try:
                get_lines_with_body = submit_file_as_list.index('<body>\n')
                list_without_lines_with_body = submit_file_as_list[
                    get_lines_with_body + 1:]
            except ValueError:
                green_foreground("If you see this message and, possibly, long output after them, "
                                 "your file " + filename_without_path + " not contains <body>. "
                                 "Please, add <body> to " + filename_without_path + " to correct place "
                                 "and rerun erichek.")
                # Check, that asterisks contains in full file
                list_without_lines_with_body = submit_file_as_list

            # Remove list item, contains «<!--»
            # https://stackoverflow.com/a/3416473/5951529
            list_without_lines_with_body_and_comments = [x for x in
                                                         list_without_lines_with_body if '<!--' not in x]
            # Check all elements of list, that contains «*»
            # https://stackoverflow.com/a/44118151/5951529
            # List comprehension: print incorrect list items
            # https://docs.python.org/3/tutorial/datastructures.html#list-comprehensions
            if all('*' in item for item in list_without_lines_with_body_and_comments):
                LOG.debug(
                    "All lines in " +
                    filename_without_path +
                    " contains asterisks")
            else:
                lines_without_asterisks = [item for item in
                                           list_without_lines_with_body_and_comments if '*' not in
                                           item]
                # Remove \n symbol in end of the lines
                # https://stackoverflow.com/a/30881893/5951529
                lines_without_asterisks_and_n = list(
                    map(str.strip, lines_without_asterisks))
                # Lists to strings with quotes
                # https://stackoverflow.com/a/13207725/5951529
                lines_without_asterisks_and_n_as_strings = str(
                    lines_without_asterisks_and_n)[1:-1]
                red_foreground("This line(s) not contains asterisks: " +
                               lines_without_asterisks_and_n_as_strings +
                               " in " +
                               filename_without_path)
                global ASTERISKS_EXISTS
                ASTERISKS_EXISTS = False


def eric_asterisks_summary():
    """Report, contains asterisks in all files or no."""
    eric_asterisks_function()
    if ASTERISKS_EXISTS:
        green_foreground("All needest lines contains asterisks")

    if not ASTERISKS_EXISTS:
        red_foreground(
            "One or more your files not contained asterisks. Please, correct your package.")



# -*- coding: utf-8 -*-
# @Author: SashaChernykh
# @Date: 2018-01-22 08:41:23
# @Last Modified time: 2018-02-01 20:50:08
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
# from setuptools import find_packages
from setuptools import setup

# Install dependencies from requirements.txt
from pip.req import parse_requirements

install_reqs = parse_requirements('requirements.txt', session='hack')

# reqs is a list of requirements
# e.g. ['django==1.5.1', 'mezzanine==1.4.6']
reqs = [str(ir.req) for ir in install_reqs]

# For Markdown README
# https://stackoverflow.com/a/26737672/5951529
setup(
    install_requires=reqs,
    # packages=find_packages()
    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('', ['README.md'])],
    # long_description=long_description
)



# -*- coding: utf-8 -*-
# @Author: Kristinita
# @Date: 2018-01-02 08:35:59
# @Last Modified time: 2018-01-26 17:30:14
# For pydocstyle:
# D301: Use r""", if any backslashes in a docstring
r"""Patorjk-HeX ASCII-art font.

        _____                                                                                _____
   _____\    \ ___________        ____________         _____         __     __          _____\    \  ______   _______
  /    / |    |\          \      /            \   _____\    \_      /  \   /  \        /    / |    ||\     \  \      \
 /    /  /___/| \    /\    \    |\___/\  \\___/| /     /|     |    /   /| |\   \      /    /  /___/| \\     \  |     /|
|    |__ |___|/  |   \_\    |    \|____\  \___|//     / /____/|   /   //   \\   \    |    |__ |___|/  \|     |/     //
|       \        |      ___/           |  |    |     | |____|/   /    \_____/    \   |       \         |     |_____//
|     __/ __     |      \  ____   __  /   / __ |     |  _____   /    /\_____/\    \  |     __/ __      |     |\     \
|\    \  /  \   /     /\ \/    \ /  \/   /_/  ||\     \|\    \ /    //\_____/\\    \ |\    \  /  \    /     /|\|     |
| \____\/    | /_____/ |\______||____________/|| \_____\|    |/____/ |       | \____\| \____\/    |  /_____/ |/_____/|
| |    |____/| |     | | |     ||           | /| |     /____/||    | |       | |    || |    |____/| |     | / |    | |
 \|____|   | | |_____|/ \|_____||___________|/  \|_____|    |||____|/         \|____| \|____|   | | |_____|/  |____|/
       |___|/                                          |____|/                              |___|/
"""

# Configuration Erichek file.
# Imports and variables for Erichek.

import glob

# logbook — custom logging:
# http://logbook.readthedocs.io/en/stable/quickstart.html
# Set NOTICE level:
# https://github.com/search?q=StreamHandler(sys.stdout).push_application()&type=Code
import logbook
import sys

# Get all .txt file in a directory
# https://stackoverflow.com/a/3964689/5951529
# «glob.glob('../*.txt')» in parent folder, not «glob.glob('../*.txt')»!
ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS = glob.glob('./*.txt')

VERSION = "0.1"


def version():
    """Show version.

    For details see:
    https://clize.readthedocs.io/en/stable/dispatching.html#alternate-actions
    """
    print(VERSION)


def v():
    """Alternative show version.

    For details see: https://github.com/epsy/clize/issues/34
    """
    print(VERSION)


def clize_log_level(*, logbook_level: 'll'="NOTICE"):
    """Change log levels via command line.

    User select, which logging messages to see. See about 6 log levels here:
    https://logbook.readthedocs.io/en/stable/quickstart.html

    :param logbook_level: user select logging level
    """
    if logbook_level == "DEBUG":
        logbook.StreamHandler(sys.stdout,
                              level=logbook.DEBUG).push_application()
    elif logbook_level == "INFO":
        logbook.StreamHandler(sys.stdout,
                              level=logbook.INFO).push_application()
    elif logbook_level == "NOTICE":
        logbook.StreamHandler(sys.stdout,
                              level=logbook.NOTICE).push_application()
    elif logbook_level == "WARNING":
        logbook.StreamHandler(sys.stdout,
                              level=logbook.WARNING).push_application()
    elif logbook_level == "ERROR":
        logbook.StreamHandler(sys.stdout,
                              level=logbook.ERROR).push_application()
    elif logbook_level == "CRITICAL":
        logbook.StreamHandler(sys.stdout,
                              level=logbook.CRITICAL).push_application()
    else:
        logbook.StreamHandler(sys.stdout,
                              level=logbook.NOTICE).push_application()



# -*- coding: utf-8 -*-
# @Author: SashaChernykh
# @Date: 2018-01-22 18:30:38
# @Last Modified time: 2018-01-26 17:31:55
"""Encoding checker.

Check, that files in Windows-1251 encoding.

Bugs:
    1. if no Cyrillic symbols in a file, chardet detect file encoding as ASCII;
    2. chardet can detect Windows-1251 as MacCyrillic.
"""
import chardet
import codecs
import logbook
import os

# Do not use «from <module> import *»
# http://bit.ly/2CuW5GS
from erichek.eric_config import ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS
from pyfancy.pyfancy import pyfancy

LOG = logbook.Logger("eric_encoding logbook")


# Flags, see https://www.computerhope.com/jargon/f/flag.htm
# https://stackoverflow.com/a/48052480/5951529
ENCODING_WINDOWS_1251 = True


def red_background(redtext):
    """Red foreground for error messages.

    Red foreground for error messages.

    Arguments:
        redtext {str} -- text, which will be colored in red.
    """
    LOG.error(pyfancy().red_bg().bold(redtext))


def green_foreground(greentext):
    """Green foreground for notice messages.

    Green foreground for error messages.

    Arguments:
        greentext {str} -- text, which will be colored in green.
    """
    LOG.notice(pyfancy().green().bold(greentext))


def eric_encoding_function():
    """Check encoding of the file.

    chardet check, that each file in Windows-1251.
    MacCyrillic — also true.
    In local testing UTF-8 convert to Cyrillic-1251.
    """
    # Get list all filenames in a directory
    # https://stackoverflow.com/a/1120736/5951529
    for filename in ALL_TXT_IN_ERIC_ROOM_WIHTOUT_SUBFOLDERS:

        filename_without_path = os.path.basename(filename)

        # Not 100%, see https://stackoverflow.com/a/436299/5951529
        # Can doesn't work for Latin packages
        # Check decoding — http://bit.ly/2C3xSUD
        # https://stackoverflow.com/a/37531241/5951529
        rawdata = open(filename, "rb").read()
        chardet_data = chardet.detect(rawdata)
        # Python dictionary
        fileencoding = (chardet_data['encoding'])
        chardet_confidence = (chardet_data['confidence'])

        # Needs MacCyrillic, because chardet can check Windows-1251
        # as MacCyrillic
        if fileencoding == 'windows-1251':
            LOG.debug(filename_without_path + " in windows-1251 encoding")
        # Integer to string:
        # https://stackoverflow.com/a/961638/5951529
        elif fileencoding == 'MacCyrillic':
            LOG.info(pyfancy().green("Encoding of file " + filename_without_path +
                                     " chardet detect as MacCyrillic with confidence " +
                                     str(chardet_confidence)))
        else:
            # Convert file from UTF-8 to Cyrillic 1251
            # https://stackoverflow.com/q/19932116/5951529
            with codecs.open(filename, "r", "utf-8") as file_for_conversion:
                read_file_for_conversion = file_for_conversion.read()
            with codecs.open(filename, "w", "windows-1251") as file_for_conversion:
                if read_file_for_conversion:
                    file_for_conversion.write(read_file_for_conversion)
            red_background(filename_without_path +
                           " in " +
                           fileencoding +
                           ", not in Windows-1251 encoding! Please, save " +
                           filename_without_path + " in Windows-1251 encoding.")
            green_foreground("If encoding of file " + filename_without_path +
                             " is UTF-8 and you see message above in local wwtd testing, " +
                             filename_without_path +
                             " automatically will converted from UTF-8 to Windows-1251.")
            global ENCODING_WINDOWS_1251
            ENCODING_WINDOWS_1251 = False


def eric_encoding_summary():
    """Report, all files in Windows-1251 or no."""
    eric_encoding_function()
    if ENCODING_WINDOWS_1251:
        green_foreground(
            "All files in Windows-1251 encoding")

    if not ENCODING_WINDOWS_1251:
        red_background(
            "One or more your files not in Windows-1251 encoding. Please, convert it (them) to Windows-1251.")
